def main():
    raise NotImplementedError()


if __name__ == "__main__":
    main()
